function idTable = loadid(idFile)
    % LOADID Load the identification file into a table.
    % -----
    %
    % Syntax:
    %   idTable = loadid(idFile) load the identification file into a Matlab table.
    %
    % Inputs:
    %   idFile: Identification file.
    %
    % Outputs:
    %   idTable: Table with the identification data.
    %
    % See also: readdata.

    % ----------------------------------------------------------------------------------------------
    % TODO: Check for inconsistencies in the table (in terms of speed, temperature, etc)
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Tweak options before import
    opts = detectImportOptions(idFile);
    opts.VariableNamesLine = 3;
    opts.VariableUnitsLine = 4;
    opts.DataLines = [5 Inf];

    % Import
    idTable = readtable(idFile, opts);
end
