function plotwindonoff(ResData)
    % PLOTWINDONON Plots the forces in wind on and wind off conditions
    %   Todo

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    set(0, 'defaulttextinterpreter', 'latex');

    POSITION = 'Front';
    INTERESTING_POINTS = [
                          0.10, 3, 4.6
                         ];
    PLOT_TIME = true;
    SAVE_TIKZ_PARAM = []; % INTERESTING_POINTS(1:2, :);
    MYGREY = [186, 216, 221] / 255;

    for i = 1:size(ResData, 1)
        for j = 1:size(ResData, 2)

            if isinteresting(ResData(i, j), INTERESTING_POINTS)

                expParam = sprintf('d = %0.2f, f = %0.2f, V = %0.1f', ...
                                   ResData(i, j).Testcase.dx, ...
                                   ResData(i, j).(POSITION).trueFreq, ...
                                   ResData(i, j).Testcase.airspeed);

                % Index of corresponding wind-off data
                woIdx = (j) - mod(j - 1, 4);

                windOff = ResData(i, woIdx).(POSITION);
                timeOff = ResData(i, woIdx).time;
                sampling = ResData(i, woIdx).sampling;
                windOn = ResData(i, j).(POSITION);
                timeOn = ResData(i, j).time;

                %% PROBABLY BETTER
                windOffPeriodIdx = getmeanperiodidx(windOff.angles, sampling, windOff.trueFreq);
                windOnPeriodIdx = getmeanperiodidx(windOn.angles, sampling, windOn.trueFreq);

                windOffIdx = windOffPeriodIdx(1):windOffPeriodIdx(2);
                windOnIdx = windOnPeriodIdx(1):windOnPeriodIdx(2);

                % Trim to same length if needed
                minLen = min(length(windOffIdx), length(windOnIdx));
                windOffIdx = windOffIdx(1:minLen);
                windOnIdx = windOnIdx(1:minLen);

                % True period
                period = 1 / windOff.trueFreq;
                nPeriodIdx = period * sampling;

                fzOff = windOff.forces(windOffIdx, 3);
                anglesOff = windOff.angles(windOffIdx);
                anglesOn = windOn.angles(windOnIdx);
                fzOn = windOn.forces(windOnIdx, 3);
                meanDiff = fzOn - fzOff;

                time = (0:length(meanDiff) - 1) / nPeriodIdx;
                [~, donwStrokeEndIdx] = min(anglesOff);

                figure;
                setcolormap();
                hold on;
                patchX = [0, donwStrokeEndIdx / nPeriodIdx, donwStrokeEndIdx / nPeriodIdx, 0];
                patchY = [-5, -5, 10, 10];

                patch(patchX, patchY, [186, 216, 221] / 255, 'EdgeColor', 'none', 'FaceAlpha', 0.5);
                h1 = plot(time, fzOff, 'LineWidth', 1.2);
                h2 = plot(time, fzOn, 'LineWidth', 1.2);
                h3 = plot(time, meanDiff, 'LineWidth', 1.2);
                text((donwStrokeEndIdx / nPeriodIdx) / 2, -2.75, ...
                     'Downstroke', ...
                     'HorizontalAlignment', 'center');
                text(donwStrokeEndIdx / nPeriodIdx + ...
                     (1 - (donwStrokeEndIdx / nPeriodIdx)) / 2, -2.75, ...
                     'Upstroke', ...
                     'HorizontalAlignment', 'center');
                setgca();
                legend([h1, h2, h3], {'\airspeed = 0 m/s', '\airspeed = 4.6 m/s', 'Difference'});
                legend('boxoff');
                xlim([0, 1]);
                ylim([-3 2]);

                if isinteresting(ResData(i, j), SAVE_TIKZ_PARAM)
                    figdir = 'figures/results/';
                    filename = sprintf('inertia-period-Dx%0.2f_F%0.2f_V%0.1f.tex', ...
                                       ResData(i, j).Testcase.dx, ...
                                       ResData(i, j).Testcase.freq, ...
                                       ResData(i, j).Testcase.airspeed);
                    save2tikz([figdir, filename], '\small');
                end
                title(expParam);

                figure;
                setcolormap();
                hold on;
                patchX = [0, donwStrokeEndIdx / nPeriodIdx, donwStrokeEndIdx / nPeriodIdx, 0];
                patchY = [-5, -5, 10, 10];

                patch(patchX, patchY, [186, 216, 221] / 255, 'EdgeColor', 'none', 'FaceAlpha', 0.5);
                h1 = plot(time, fzOff, 'LineWidth', 1.2);
                h2 = plot(time, fzOn, 'LineWidth', 1.2);
                h3 = plot(time, meanDiff, 'LineWidth', 1.2);
                text((donwStrokeEndIdx / nPeriodIdx) / 2, -2.75, ...
                     'Downstroke', ...
                     'HorizontalAlignment', 'center');
                text(donwStrokeEndIdx / nPeriodIdx + ...
                     (1 - (donwStrokeEndIdx / nPeriodIdx)) / 2, -2.75, ...
                     'Upstroke', ...
                     'HorizontalAlignment', 'center');
                setgcpres();
                % legend([h1, h2, h3], {'\airspeed = 0 m/s', '\airspeed = 4.6 m/s', 'Difference'});
                % legend('boxoff');
                xlim([0, 1]);
                ylim([-3 2]);
                v0pos = 0.5;
                vInfpos = 0.25;
                diffpos = 0.6;
                text(v0pos, fzOff(round(v0pos * length(time))) * 0.9, ...
                     '$\mathbf{V_0}$', ...
                     'HorizontalAlignment', 'right', 'Color', h1.Color);
                text(vInfpos, fzOn(round(vInfpos * length(time))) * 1.1, ...
                     '$\mathbf{\airspeed}$', ...
                     'HorizontalAlignment', 'left', 'Color', h2.Color);
                text(diffpos, meanDiff(round(diffpos * length(time))) * 1.1, ...
                     '$\mathbf{\airspeed - V_0}$', ...
                     'HorizontalAlignment', 'left', 'Color', h3.Color);

                if isinteresting(ResData(i, j), SAVE_TIKZ_PARAM)
                    figdir = 'figures/results/';
                    filename = sprintf('inertia-period-Dx%0.2f_F%0.2f_V%0.1f_PRES.tex', ...
                                       ResData(i, j).Testcase.dx, ...
                                       ResData(i, j).Testcase.freq, ...
                                       ResData(i, j).Testcase.airspeed);
                    save2tikz([figdir, filename], '\small');
                end
                title(expParam);

                % figure;
                % hold on;
                % plot(time, fzOff);
                % plot(time, fzOn);
                % plot(time, meanDiff);
                % plot(time(round(end / 5)), fzOn(round(end / 5)), 'or');
                % yyaxis right;
                % plot(time, windOff.angles(windOffIdx));
                % title(expParam);
                % legend('Wind off', 'Wind on', 'Diff');
                % grid on;
                % xlim([0, 1]);
                %
                % figure;
                % ax1 = subplot(3, 1, 1);
                % setcolormap();
                % hold on;
                %
                % plot(anglesOn, fzOn);
                % plot(anglesOn(round(end / 5)), fzOn(round(end / 5)), 'or');
                % setgca('XTickLabel', [], ...
                %        'YLabel', [], ...
                %        'XLabel', []);
                %
                % ax2 =  subplot(3, 1, 2);
                % setcolormap();
                % hold on;
                % plot(anglesOff, fzOff);
                % % plot(meanPeakAngle(round(end / 5)), meanPeakFoff(round(end / 5)), 'or');
                % setgca('XTickLabel', [], ...
                %        'XLabel', []);
                %
                % ax3 =  subplot(3, 1, 3);
                % setcolormap();
                % hold on;
                % plot(anglesOff, meanDiff);
                % % plot(meanPeakAngle(round(end / 5)), meanDiff(round(end / 5)), 'or');
                % linkaxes([ax1 ax2 ax3], 'xy');
                % ax1.YLim = 1.25 * ax1.YLim;
                % setgca('YLabel', []);
                %
                % if isinteresting(ResData(i, j), SAVE_TIKZ_PARAM)
                %     figdir = 'figures/results/';
                %     filename = sprintf('inertia-Dx%0.2f_F%0.2f_V%0.1f.tex', ...
                %                        ResData(i, j).Testcase.dx, ...
                %                        ResData(i, j).Testcase.freq, ...
                %                        ResData(i, j).Testcase.airspeed);
                %     save2tikz([figdir, filename], '\small');
                % end %
                %
                % figure;
                % hold on;
                % plot(time, fzOff);
                % plot(time, fzOn);
                % plot(time, meanDiff);
                % plot(time(round(end / 5)), fzOn(round(end / 5)), 'or');
                % yyaxis right;
                % plot(time, windOff.angles(windOffIdx));
                % title(expParam);
                % legend('Wind off', 'Wind on', 'Diff');
                % grid on;
                % xlim([0, 1]);
                %
                % figure;
                % ax1 = subplot(3, 1, 1);
                % setcolormap();
                % hold on;
                %
                % plot(anglesOn, fzOn);
                % plot(anglesOn(round(end / 5)), fzOn(round(end / 5)), 'or');
                % setgca('XTickLabel', [], ...
                %        'YLabel', [], ...
                %        'XLabel', []);
                %
                % ax2 =  subplot(3, 1, 2);
                % setcolormap();
                % hold on;
                % plot(anglesOff, fzOff);
                % % plot(meanPeakAngle(round(end / 5)), meanPeakFoff(round(end / 5)), 'or');
                % setgca('XTickLabel', [], ...
                %        'XLabel', []);
                %
                % ax3 =  subplot(3, 1, 3);
                % setcolormap();
                % hold on;
                % plot(anglesOff, meanDiff);
                % % plot(meanPeakAngle(round(end / 5)), meanDiff(round(end / 5)), 'or');
                % linkaxes([ax1 ax2 ax3], 'xy');
                % ax1.YLim = 1.25 * ax1.YLim;
                % setgca('YLabel', []);
                %
                % if isinteresting(ResData(i, j), SAVE_TIKZ_PARAM)
                %     figdir = 'figures/results/';
                %     filename = sprintf('inertia-Dx%0.2f_F%0.2f_V%0.1f.tex', ...
                %                        ResData(i, j).Testcase.dx, ...
                %                        ResData(i, j).Testcase.freq, ...
                %                        ResData(i, j).Testcase.airspeed);
                %     save2tikz([figdir, filename], '\small');
                % end
                % % Add titles after having saved
                % title(ax1, ['Wind on - ', expParam]);
                % title(ax2, ['Wind off - ', expParam]);
                % title(ax3, ['Diff - ', expParam]);
                %
                % % Add titles after having saved
                % title(ax1, ['Wind on - ', expParam]);
                % title(ax2, ['Wind off - ', expParam]);
                % title(ax3, ['Diff - ', expParam]);

            end

        end
    end

end

function meanPeriod = getmeanperiodidx(signal, sampling, freq)
    % GETMEANPEAK Return bounds of a period somewhere in the signal

    period = 1 / freq;
    nPeriodIdx = period * sampling;
    peakLocs = getallpeaks(signal, sampling);

    % Remove first and last peaks
    peakLocs = peakLocs(2:end - 1);

    meanPeriod = [peakLocs(round(end / 3)), peakLocs(round(end / 3)) + nPeriodIdx];

end

function setgca(varargin)

    xlabel('t/T [-]');
    ylabel('\fz [N]');

    xticks([0:0.25:1]);

    set(gca, ...
        'Box', 'off', ...
        'TickDir', 'out', ...
        'TickLength', [.02 .02], ...
        'XMinorTick', 'off', ...
        'YMinorTick', 'off', ...
        'YGrid', 'off', ...
        'XGrid', 'off', ...
        'XColor', 'k', ...
        'YColor', 'k', ...
        'GridLineStyle', ':', ...
        'GridColor', 'k', ...
        'GridAlpha', 0.25, ...
        'LineWidth', 1, ...
        'FontName', 'Helvetica', ...
        'Fontsize', 14);

    if nargin > 0
        set(gca, varargin{:});
    end

end

function setgcpres(varargin)

    xlabel('t');
    ylabel('\fz');

    set(gca, ...
        'Box', 'off', ...
        'TickDir', 'out', ...
        'TickLength', [.02 .02], ...
        'XMinorTick', 'off', ...
        'YMinorTick', 'off', ...
        'YGrid', 'off', ...
        'XGrid', 'off', ...
        'XColor', 'k', ...
        'YColor', 'k', ...
        'GridLineStyle', ':', ...
        'GridColor', 'k', ...
        'GridAlpha', 0.25, ...
        'LineWidth', 1, ...
        'FontName', 'Helvetica', ...
        'XTickLabel', [], ...
        'YTickLabel', [], ...
        'XTick', [], ...
        'YTick', [], ...
        'Fontsize', 14);

    if nargin > 0
        set(gca, varargin{:});
    end

end
